@@ -2,11 +2,13 @@ import typing
 from dataclasses import dataclass
 
 import pandas as pd
+from pandas.io.sql import pandasSQL_builder
 from sqlalchemy import create_engine  # type: ignore
 
 from flytekit import current_context, kwtypes
+from flytekit.configuration import SerializationSettings
+from flytekit.configuration.default_images import DefaultImages, PythonVersion
 from flytekit.core.base_sql_task import SQLTask
-from flytekit.core.context_manager import SerializationSettings
 from flytekit.core.python_customized_container_task import PythonCustomizedContainerTask
 from flytekit.core.shim_task import ShimTaskExecutor
 from flytekit.models import task as task_models
@@ -14,6 +16,16 @@ from flytekit.models.security import Secret
 from flytekit.types.schema import FlyteSchema
 
 
+class SQLAlchemyDefaultImages(DefaultImages):
+    """Default images for the sqlalchemy flytekit plugin."""
+
+    _DEFAULT_IMAGE_PREFIXES = {
+        PythonVersion.PYTHON_3_8: "cr.flyte.org/flyteorg/flytekit:py3.8-sqlalchemy-",
+        PythonVersion.PYTHON_3_9: "cr.flyte.org/flyteorg/flytekit:py3.9-sqlalchemy-",
+        PythonVersion.PYTHON_3_10: "cr.flyte.org/flyteorg/flytekit:py3.10-sqlalchemy-",
+    }
+
+
 @dataclass
 class SQLAlchemyConfig(object):
     """
@@ -58,11 +70,10 @@ class SQLAlchemyConfig(object):
 class SQLAlchemyTask(PythonCustomizedContainerTask[SQLAlchemyConfig], SQLTask[SQLAlchemyConfig]):
     """
     Makes it possible to run client side SQLAlchemy queries that optionally return a FlyteSchema object
-
-    TODO: How should we use pre-built containers for running portable tasks like this. Should this always be a
-          referenced task type?
     """
 
+    # TODO: How should we use pre-built containers for running portable tasks like this? Should this always be a referenced task type?
+
     _SQLALCHEMY_TASK_TYPE = "sqlalchemy"
 
     def __init__(
@@ -71,12 +82,14 @@ class SQLAlchemyTask(PythonCustomizedContainerTask[SQLAlchemyConfig], SQLTask[SQ
         query_template: str,
         task_config: SQLAlchemyConfig,
         inputs: typing.Optional[typing.Dict[str, typing.Type]] = None,
-        output_schema_type: typing.Optional[typing.Type[FlyteSchema]] = None,
-        container_image: str = "ghcr.io/flyteorg/flytekit:sqlalchemy-75fc68cd2d0a71588359039f94daab09d68cac11",
+        output_schema_type: typing.Optional[typing.Type[FlyteSchema]] = FlyteSchema,
+        container_image: str = SQLAlchemyDefaultImages.default_image(),
         **kwargs,
     ):
-        output_schema = output_schema_type if output_schema_type else FlyteSchema
-        outputs = kwtypes(results=output_schema)
+        if output_schema_type:
+            outputs = kwtypes(results=output_schema_type)
+        else:
+            outputs = None
 
         super().__init__(
             name=name,
@@ -117,5 +130,9 @@ class SQLAlchemyTaskExecutor(ShimTaskExecutor[SQLAlchemyTask]):
         interpolated_query = SQLAlchemyTask.interpolate_query(tt.custom["query_template"], **kwargs)
         print(f"Interpolated query {interpolated_query}")
         with engine.begin() as connection:
-            df = pd.read_sql_query(interpolated_query, connection)
+            df = None
+            if tt.interface.outputs:
+                df = pd.read_sql_query(interpolated_query, connection)
+            else:
+                pandasSQL_builder(connection).execute(interpolated_query)
         return df
